tinyfiledialogs

package module
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: Zlib Imports: 2 Imported by: 0

README

tinyfiledialogs bindings for go

Golang bindings for tinyfiledialogs, a simple, cross-platform library for native dialogs.

The C code is included and compiled together with the bindings.

Installation

go get -v -u github.com/wizzymore/tinyfiledialogs

The tinyfiledialogs version used is: v3.18.1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func OpenFileDialog

func OpenFileDialog(title string, defaultPathOrFile string, filePatterns []string, singleFilterDescription string, allowMultipleSelection bool) (path string, ok bool)

OpenFileDialog opens a file selection dialog.

title - the title of the dialog.

defaultPathOrFile - the default path or file to open. For directories, use a trailing slash.

filePatterns is a list of file patterns to filter the files.

singleFilterDescription is the description of the filter.

allowMultipleSelection is a boolean to allow multiple file selection.

Returns the selected file(s). If multiple files are selected, they are separated by a pipe character "|".

func SaveFileDialog

func SaveFileDialog(title string, defaultPathOrFile string, filePatterns []string, singleFilterDescription string) (path string, ok bool)

SaveFileDialog opens a file selection dialog.

title - the title of the dialog.

defaultPathOrFile - the default path or file to open. For directories, use a trailing slash.

filePatterns is a list of file patterns to filter the files.

singleFilterDescription is the description of the filter.

Returns the selected file(s). If multiple files are selected, they are separated by a pipe character "|".

func SelectFolderDialog

func SelectFolderDialog(title string, defaultPath string) (path string, ok bool)

title - the title of the dialog. defaultPath - the default path to open. The selected folder is not returned with a trailing slash compared to the tinyfd default behaviour. If you want the trailing slash use SelectFolderDialogT

Types

This section is empty.

Directories

Path Synopsis

Jump to